==> react-native-userx-1.3.0.tgz: package/android/src/main/java/pro/userx/UserXModule.java <==
package pro.userx;

import android.graphics.Rect;
import android.os.Handler;
import android.view.View;

import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.uimanager.NativeViewHierarchyManager;
import com.facebook.react.uimanager.UIBlock;
import com.facebook.react.uimanager.UIManagerModule;

import java.util.HashMap;

public class UserXModule extends ReactContextBaseJavaModule {

    public UserXModule(ReactApplicationContext reactContext) {
        super(reactContext);
    }

    @Override
    public String getName() {
        return "UserX";
    }

    @ReactMethod
    public void start(String key) {
        UserX.init(key);
    }

    @ReactMethod
    public static void setUserId(String userId) {
        UserX.setUserId(userId);
    }

    @ReactMethod
    public static String getUserId() {
        return UserX.getUserId();
    }

    @ReactMethod
    public static void addEvent(String name) {
        UserX.addEvent(name);
    }

    @ReactMethod
    public static void addEvent(String name, ReadableMap attributes) {
        if (attributes == null) {
            UserX.addEvent(name);
            return;
        }
        HashMap<String, Object> reactMap = attributes.toHashMap();
        HashMap<String, String> userxMap = new HashMap<>();
        for (String k : reactMap.keySet()) {
            userxMap.put(k, reactMap.get(k).toString());
        }
        UserX.addEvent(name, userxMap);
    }

    @ReactMethod
    public void addScreenName(String name) {
        UserX.addScreenName(name);
    }

    @ReactMethod
    public static void setCatchExceptions(boolean catchExceptions) {
        UserX.setCatchExceptions(catchExceptions);
    }

    @ReactMethod
    public static void setKeyboardRenderingEnabled(boolean isKeyboardRenderingEnabled) {
        UserX.setKeyboardRenderingEnabled(isKeyboardRenderingEnabled);
    }

    @ReactMethod
    public static void setScrollRenderingEnabled(boolean isScrollRenderingEnabled) {
        UserX.setScrollRenderingEnabled(isScrollRenderingEnabled);
    }

    @ReactMethod
    public static void setLowVideoQuality() {
        UserX.setLowVideoQuality();
    }

    @ReactMethod
    public static void setMediumVideoQuality() {
        UserX.setMediumVideoQuality();
    }

    @ReactMethod
    public static void setHighVideoQuality() {
        UserX.setHighVideoQuality();
    }

    @ReactMethod
    public static void setMaxSpaceSize(int maxSpaceSize) {
        UserX.setMaxSpaceSize(maxSpaceSize);
    }

    @ReactMethod
    public static void startScreenRecording() {
        UserX.startScreenRecording();
    }

    @ReactMethod
    public static void stopScreenRecording() {
        UserX.stopScreenRecording();
    }

    @ReactMethod
    public static boolean isFullVideoRecording() {
        return UserX.isFullVideoRecording();
    }

    @ReactMethod
    public static String getSessionUrl() {
        return UserX.getSessionUrl();
    }

//    @ReactMethod
//    public String getExternalAnalyticsUrl() {
//        return UserX.getExternalAnalyticsUrl();
//    }

    @ReactMethod
    public void setGoogleMapView(final int id, int googleMapSnapshotPeriod) {
        UIManagerModule uiManager = getReactApplicationContext().getNativeModule(UIManagerModule.class);
        uiManager.addUIBlock(new UIBlock() {
            @Override
            public void execute(NativeViewHierarchyManager nativeViewHierarchyManager) {
                try {
                    View view = nativeViewHierarchyManager.resolveView(id);
                    if (view != null) {
                        UserX.setGoogleMap(view);
                    }
                } catch (Exception e) {
                }
            }
        });
    }

    @ReactMethod
    public void showSensitiveView(final int id) {
        UIManagerModule uiManager = getReactApplicationContext().getNativeModule(UIManagerModule.class);
        uiManager.addUIBlock(new UIBlock() {
            @Override
            public void execute(NativeViewHierarchyManager nativeViewHierarchyManager) {
                try {
                    View view = nativeViewHierarchyManager.resolveView(id);
                    if (view != null)
                        UserX.removeSensitiveView(view);
                } catch (Exception e) {
                }
            }
        });
    }

    @ReactMethod
    public void hideSensitiveView(final int id) {
        UIManagerModule uiManager = getReactApplicationContext().getNativeModule(UIManagerModule.class);
        uiManager.addUIBlock(new UIBlock() {
            @Override
            public void execute(NativeViewHierarchyManager nativeViewHierarchyManager) {
                try {
                    final View view = nativeViewHierarchyManager.resolveView(id);
                    if (view != null) {
                        UserX.addSensitiveView(view);
                    }
                } catch (Exception e) {
                }
            }
        });
    }

    @ReactMethod
    public void showAllSensitiveViews() {
        UserX.removeAllSensitiveViews();
    }

}

==> react-native-userx-1.3.6.tgz: package/android/src/main/java/pro/userx/UserXModule.java <==
package pro.userx;

import android.graphics.Rect;
import android.os.Handler;
import android.view.View;

import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.uimanager.NativeViewHierarchyManager;
import com.facebook.react.uimanager.UIBlock;
import com.facebook.react.uimanager.UIManagerModule;

import java.util.HashMap;

public class UserXModule extends ReactContextBaseJavaModule {

    public UserXModule(ReactApplicationContext reactContext) {
        super(reactContext);
    }

    @Override
    public String getName() {
        return "UserX";
    }

    @ReactMethod
    public void start(String key, boolean uploadIfMarked) {
        UserX.init(key, uploadIfMarked);
        UserX.setTextChangeWatchersEnabled(false);
    }

    @ReactMethod
    public static void setUserId(String userId) {
        UserX.setUserId(userId);
    }

    @ReactMethod
    public static String getUserId() {
        return UserX.getUserId();
    }

    @ReactMethod
    public static void addEvent(String name) {
        UserX.addEvent(name);
    }

    @ReactMethod
    public static void addEvent(String name, ReadableMap attributes) {
        if (attributes == null) {
            UserX.addEvent(name);
            return;
        }
        HashMap<String, Object> reactMap = attributes.toHashMap();
        HashMap<String, String> userxMap = new HashMap<>();
        for (String k : reactMap.keySet()) {
            userxMap.put(k, reactMap.get(k).toString());
        }
        UserX.addEvent(name, userxMap);
    }

    @ReactMethod
    public void addScreenName(String name) {
        UserX.addScreenName(name);
    }

    @ReactMethod
    public static void setCatchExceptions(boolean catchExceptions) {
        UserX.setCatchExceptions(catchExceptions);
    }

    @ReactMethod
    public static void setKeyboardRenderingEnabled(boolean isKeyboardRenderingEnabled) {
        UserX.setKeyboardRenderingEnabled(isKeyboardRenderingEnabled);
    }

    @ReactMethod
    public static void setScrollRenderingEnabled(boolean isScrollRenderingEnabled) {
        UserX.setScrollRenderingEnabled(isScrollRenderingEnabled);
    }

    @ReactMethod
    public static void setLowVideoQuality() {
        UserX.setLowVideoQuality();
    }

    @ReactMethod
    public static void setMediumVideoQuality() {
        UserX.setMediumVideoQuality();
    }

    @ReactMethod
    public static void setHighVideoQuality() {
        UserX.setHighVideoQuality();
    }

    @ReactMethod
    public static void setMaxSpaceSize(int maxSpaceSize) {
        UserX.setMaxSpaceSize(maxSpaceSize);
    }

    @ReactMethod
    public static void startScreenRecording() {
        UserX.startScreenRecording();
    }

    @ReactMethod
    public static void stopScreenRecording() {
        UserX.stopScreenRecording();
    }

    @ReactMethod
    public static boolean isFullVideoRecording() {
        return UserX.isFullVideoRecording();
    }

    @ReactMethod
    public static String getSessionUrl() {
        return UserX.getSessionUrl();
    }

//    @ReactMethod
//    public String getExternalAnalyticsUrl() {
//        return UserX.getExternalAnalyticsUrl();
//    }

    @ReactMethod
    public void setGoogleMapView(final int id, int googleMapSnapshotPeriod) {
        UIManagerModule uiManager = getReactApplicationContext().getNativeModule(UIManagerModule.class);
        uiManager.addUIBlock(new UIBlock() {
            @Override
            public void execute(NativeViewHierarchyManager nativeViewHierarchyManager) {
                try {
                    View view = nativeViewHierarchyManager.resolveView(id);
                    if (view != null) {
                        UserX.setGoogleMap(view);
                    }
                } catch (Exception e) {
                }
            }
        });
    }

    @ReactMethod
    public void showSensitiveView(final int id) {
        UIManagerModule uiManager = getReactApplicationContext().getNativeModule(UIManagerModule.class);
        uiManager.addUIBlock(new UIBlock() {
            @Override
            public void execute(NativeViewHierarchyManager nativeViewHierarchyManager) {
                try {
                    View view = nativeViewHierarchyManager.resolveView(id);
                    if (view != null)
                        UserX.removeSensitiveView(view);
                } catch (Exception e) {
                }
            }
        });
    }

    @ReactMethod
    public void hideSensitiveView(final int id) {
        UIManagerModule uiManager = getReactApplicationContext().getNativeModule(UIManagerModule.class);
        uiManager.addUIBlock(new UIBlock() {
            @Override
            public void execute(NativeViewHierarchyManager nativeViewHierarchyManager) {
                try {
                    final View view = nativeViewHierarchyManager.resolveView(id);
                    if (view != null) {
                        UserX.addSensitiveView(view);
                    }
                } catch (Exception e) {
                }
            }
        });
    }

    @ReactMethod
    public void showAllSensitiveViews() {
        UserX.removeAllSensitiveViews();
    }

}
